@@ -1,26 +1,14 @@
-#ifndef AI_INPUT_H
-#define AI_INPUT_H
 /*
-   This file is part of the KDE games lskat program
-   Copyright (c) 2006 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games lskat program
+    SPDX-FileCopyrightText: 2006 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-// KDE includes
+#ifndef AI_INPUT_H
+#define AI_INPUT_H
+
+// KF includes
 #include "lskat_debug.h"
 
 // Local includes
@@ -55,7 +43,7 @@ public:
      */
     InputDevice::InputDeviceType type() override {return InputDevice::TypeAiInput;}
 
-public slots:
+public Q_SLOTS:
     /**
      * AI turn is performed.
      */
