@@ -1,21 +1,8 @@
 /*
-   This file is part of the KDE games lskat program
-   Copyright (c) 2006 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games lskat program
+    SPDX-FileCopyrightText: 2006 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef ENGINE_TWO_H
@@ -23,7 +10,7 @@
 
 // Qt includes
 
-// KDE includes
+// KF includes
 
 // Local includes
 #include "abstractengine.h"
@@ -87,7 +74,7 @@ public:
      */
     Suite trump() const {return mTrump;}
 
-public slots:
+public Q_SLOTS:
     /**
      * Player input available
      * @param inputId      The input device id
@@ -115,7 +102,7 @@ public slots:
      */
     static int whoWonMove(int card1, int card2, Suite trump);
 
-protected slots:
+protected Q_SLOTS:
     /**
      * First part of the game loop.
      */
